package com.xzzn.web.controller.ems;

import com.xzzn.ems.domain.EmsMqttMessage;
import com.xzzn.ems.service.IEmsMqttMessageService;
import com.xzzn.ems.service.IFXXDataProcessService;
import com.xzzn.framework.manager.MqttLifecycleManager;
import com.xzzn.framework.web.service.MqttPublisher;
import com.xzzn.framework.web.service.MqttSubscriber;
import org.apache.juli.logging.Log;
import org.apache.juli.logging.LogFactory;
import org.eclipse.paho.client.mqttv3.IMqttMessageListener;
import org.eclipse.paho.client.mqttv3.MqttException;
import org.eclipse.paho.client.mqttv3.MqttMessage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.PostConstruct;

@Service
public class MqttMessageController implements MqttPublisher, MqttSubscriber {


    private static final Log log = LogFactory.getLog(MqttMessageController.class);


    private final MqttLifecycleManager mqttLifecycleManager;

    @Autowired
    private IEmsMqttMessageService emsMqttMessageService;

    @Autowired
    private IFXXDataProcessService fXXDataProcessService;

    @Autowired
    public MqttMessageController(MqttLifecycleManager mqttLifecycleManager) {
        this.mqttLifecycleManager = mqttLifecycleManager;
    }

    @PostConstruct
    public void init() {
        // 订阅系统状态主题
        subscribe("021_FXX_01_UP", 1, this::handleDeviceData);
        subscribe("021_FXX_01_RECALL", 1, this::handleDeviceData);
        subscribe("021_FXX_01_DOWN", 1, this::handleDeviceData);
        subscribe("021_FXX_01", 1, this::handleSystemStatus);

    }

    // 处理系统状态消息
    private void handleSystemStatus(String topic, MqttMessage message) {
        String payload = new String(message.getPayload());
        System.out.println("[SYSTEM] Status update: " + payload);

        try {
            // 业务处理逻辑
            EmsMqttMessage mqttMessage = new EmsMqttMessage();
            mqttMessage.setMqttTopic(topic);
            mqttMessage.setMqttMessage(payload);
            mqttMessage.setCreateTime(new java.util.Date());
            mqttMessage.setUpdateTime(new java.util.Date());
            mqttMessage.setCreateBy("system");
            mqttMessage.setUpdateBy("system");
            emsMqttMessageService.insertEmsMqttMessage(mqttMessage);
        } catch (Exception e) {
            log.error("Failed to process system status message: " + e.getMessage(), e);
        }
    }

    // 处理设备数据
    private void handleDeviceData(String topic, MqttMessage message) {
        String payload = new String(message.getPayload());
        System.out.println("[DEVICE] data: " + payload);
        try {
            // 业务处理逻辑
            fXXDataProcessService.handleFxData(payload);


            EmsMqttMessage mqttMessage = new EmsMqttMessage();
            mqttMessage.setMqttTopic(topic);
            mqttMessage.setMqttMessage(payload);
            mqttMessage.setCreateTime(new java.util.Date());
            mqttMessage.setUpdateTime(new java.util.Date());
            mqttMessage.setCreateBy("system");
            mqttMessage.setUpdateBy("system");
            emsMqttMessageService.insertEmsMqttMessage(mqttMessage);
        } catch (Exception e) {
            log.error("Failed to process system status message: " + e.getMessage(), e);
        }

    }

    @Override
    public void publish(String topic, String message) throws MqttException {
        mqttLifecycleManager.publish(topic, message, 0);
    }

    @Override
    public void publish(String topic, String message, int qos) throws MqttException {
        mqttLifecycleManager.publish(topic, message, qos);
    }

    @Override
    public void subscribe(String topic, int qos, IMqttMessageListener listener) {
        mqttLifecycleManager.subscribe(topic, qos, listener);


    }

    // 发送设备控制命令
    public void sendDeviceCommand(String deviceId, String command) {
        try {
            String topic = "devices/" + deviceId + "/commands";
            publish(topic, command, 1);
        } catch (MqttException e) {
            System.err.println("Failed to send command to device " + deviceId);
        }
    }



}